==> nextcloud-18.0.2.tgz: nextcloud/apps/workflowengine/l10n/ja.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "指定された演算子は無効",
    "The given regular expression is invalid" : "指定の正規表現は無効",
    "The given file size is invalid" : "指定されたファイルサイズは無効",
    "The given tag id is invalid" : "指定されたIDタグは無効",
    "The given IP range is invalid" : "指定されたIP範囲は無効",
    "The given IP range is not valid for IPv4" : "指定されたIPはIPv4の範囲ではありません",
    "The given IP range is not valid for IPv6" : "指定されたIPはIPv6の範囲ではありません",
    "The given time span is invalid" : "指定された期間は無効です",
    "The given start time is invalid" : "指定された開始時刻は無効です",
    "The given end time is invalid" : "指定された終了時刻は無効です",
    "The given group does not exist" : "指定されたグループは存在しません",
    "File" : "ファイル",
    "Operation #%s does not exist" : "#%s 操作は存在しません",
    "Operation %s does not exist" : "%s 操作は存在しません",
    "Operation %s is invalid" : "%s 操作は無効です",
    "Check %s does not exist" : "チェック %s は存在しません",
    "Check %s is invalid" : "チェック %s は無効です",
    "Check #%s does not exist" : "チェック #%s は存在しません",
    "Check %s is invalid or does not exist" : "%sのチェックは無効か存在しません",
    "Flow" : "Flow",
    "Folder" : "フォルダー",
    "Images" : "画像",
    "No results" : "該当なし",
    "%s (invisible)" : "%s (不可視)",
    "%s (restricted)" : "%s (制限)",
    "Predefined URLs" : "定義済みのURL",
    "Files WebDAV" : "ファイルWebDAV",
    "Android client" : "アンドロイドクライアント",
    "iOS client" : "iOSクライアント",
    "Desktop client" : "デスクトップクライアント",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook アドオン",
    "Cancel" : "キャンセル",
    "Delete" : "削除",
    "Active" : "アクティブ化",
    "Save" : "保存",
    "Browse the app store" : "アプリストアをブラウザでみる",
    "matches" : "合致",
    "does not match" : "一致しない",
    "is" : "は",
    "is not" : "は異なる",
    "File name" : "ファイル名",
    "File MIME type" : "ファイルMIMEタイプ",
    "File size (upload)" : "ファイルサイズ（アップロード）",
    "less" : "より小さい",
    "less or equals" : "より小さいか等しい",
    "greater or equals" : "大きいか等しい",
    "greater" : "大きい",
    "Request remote address" : "リクエスト リモートアドレス",
    "matches IPv4" : "次の IPv4アドレスに合致",
    "does not match IPv4" : "次の IPv4アドレスに合致しない",
    "matches IPv6" : "次の IPv6アドレスに合致",
    "does not match IPv6" : "次の IPv6アドレスに合致しない",
    "File system tag" : "ファイルシステムタグ",
    "is tagged with" : "に次のタグが付いている",
    "is not tagged with" : "に次のタグが付いていない",
    "Request URL" : "呼びだしたURL",
    "Request time" : "ルール適用の時刻",
    "between" : "間",
    "not between" : "間ではない",
    "Request user agent" : "リクエスト時のユーザーエージェント",
    "User group membership" : "ユーザーがグループのメンバーかどうか",
    "is member of" : "が次のグループのメンバーである",
    "is not member of" : "が次のグループのメンバーではない",
    "Short rule description" : "ルールの簡潔な説明",
    "Add rule" : "ルールを追加",
    "Reset" : "リセット",
    "Saving…" : "保存中...",
    "Group list is empty" : "グループリストが空です",
    "Unable to retrieve the group list" : "グループリストを取得できません",
    "Saved" : "保存しました",
    "Saving failed:" : "保存に失敗しました：",
    "Add rule group" : "ルールグループを追加する",
    "Example: {placeholder}" : "例: {プレースホルダー}",
    "Select tag…" : "タグを選択...",
    "Start" : "開始",
    "End" : "終了",
    "Select timezone…" : "タイムゾーンを選択...",
    "Sync clients" : "同期クライアントタイプ",
    "Tag management" : "タグ管理",
    "Files workflow engine" : "ファイルワークフローエンジン",
    "Open documentation" : "ドキュメントを開く",
    "Loading…" : "読み込み中..."
},
"nplurals=1; plural=0;");

==> nextcloud-18.0.4.tgz: nextcloud/apps/workflowengine/l10n/ja.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "指定された演算子は無効",
    "The given regular expression is invalid" : "指定の正規表現は無効",
    "The given file size is invalid" : "指定されたファイルサイズは無効",
    "The given tag id is invalid" : "指定されたIDタグは無効",
    "The given IP range is invalid" : "指定されたIP範囲は無効",
    "The given IP range is not valid for IPv4" : "指定されたIPはIPv4の範囲ではありません",
    "The given IP range is not valid for IPv6" : "指定されたIPはIPv6の範囲ではありません",
    "The given time span is invalid" : "指定された期間は無効です",
    "The given start time is invalid" : "指定された開始時刻は無効です",
    "The given end time is invalid" : "指定された終了時刻は無効です",
    "The given group does not exist" : "指定されたグループは存在しません",
    "File" : "ファイル",
    "File created" : "ファイル作成時",
    "File updated" : "ファイル更新時",
    "File renamed" : "ファイル名変更時",
    "File deleted" : "ファイル削除時",
    "File accessed" : "ファイルアクセス時",
    "File copied" : "ファイル複製時",
    "Tag assigned" : "タグ割り当て時",
    "Someone" : "誰か",
    "Operation #%s does not exist" : "#%s 操作は存在しません",
    "Operation %s does not exist" : "%s 操作は存在しません",
    "Operation %s is invalid" : "%s 操作は無効です",
    "Check %s does not exist" : "チェック %s は存在しません",
    "Check %s is invalid" : "チェック %s は無効です",
    "Check #%s does not exist" : "チェック #%s は存在しません",
    "Check %s is invalid or does not exist" : "%sのチェックは無効か存在しません",
    "Flow" : "Flow",
    "Folder" : "フォルダー",
    "Images" : "画像",
    "No results" : "該当なし",
    "%s (invisible)" : "%s (不可視)",
    "%s (restricted)" : "%s (制限)",
    "Predefined URLs" : "定義済みのURL",
    "Files WebDAV" : "ファイルWebDAV",
    "Android client" : "アンドロイドクライアント",
    "iOS client" : "iOSクライアント",
    "Desktop client" : "デスクトップクライアント",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook アドオン",
    "Cancel" : "キャンセル",
    "Delete" : "削除",
    "The configuration is invalid" : "設定が正しくありません",
    "Active" : "アクティブ化",
    "Save" : "保存",
    "Browse the app store" : "アプリストアをブラウザでみる",
    "matches" : "合致",
    "does not match" : "一致しない",
    "is" : "は",
    "is not" : "は異なる",
    "File name" : "ファイル名",
    "File MIME type" : "ファイルMIMEタイプ",
    "File size (upload)" : "ファイルサイズ（アップロード）",
    "less" : "より小さい",
    "less or equals" : "より小さいか等しい",
    "greater or equals" : "大きいか等しい",
    "greater" : "大きい",
    "Request remote address" : "リクエスト リモートアドレス",
    "matches IPv4" : "次の IPv4アドレスに合致",
    "does not match IPv4" : "次の IPv4アドレスに合致しない",
    "matches IPv6" : "次の IPv6アドレスに合致",
    "does not match IPv6" : "次の IPv6アドレスに合致しない",
    "File system tag" : "ファイルシステムタグ",
    "is tagged with" : "に次のタグが付いている",
    "is not tagged with" : "に次のタグが付いていない",
    "Request URL" : "呼びだしたURL",
    "Request time" : "ルール適用の時刻",
    "between" : "間",
    "not between" : "間ではない",
    "Request user agent" : "リクエスト時のユーザーエージェント",
    "User group membership" : "ユーザーがグループのメンバーかどうか",
    "is member of" : "が次のグループのメンバーである",
    "is not member of" : "が次のグループのメンバーではない",
    "Short rule description" : "ルールの簡潔な説明",
    "Add rule" : "ルールを追加",
    "Reset" : "リセット",
    "Saving…" : "保存中...",
    "Group list is empty" : "グループリストが空です",
    "Unable to retrieve the group list" : "グループリストを取得できません",
    "Saved" : "保存しました",
    "Saving failed:" : "保存に失敗しました：",
    "Add rule group" : "ルールグループを追加する",
    "Example: {placeholder}" : "例: {プレースホルダー}",
    "Select tag…" : "タグを選択...",
    "Start" : "開始",
    "End" : "終了",
    "Select timezone…" : "タイムゾーンを選択...",
    "Sync clients" : "同期クライアントタイプ",
    "Tag management" : "タグ管理",
    "Files workflow engine" : "ファイルワークフローエンジン",
    "Open documentation" : "ドキュメントを開く",
    "Loading…" : "読み込み中..."
},
"nplurals=1; plural=0;");
